@@ -59,7 +59,8 @@ THE SOFTWARE.
 typedef struct _edOptions {   /* Global 'edit' options */
     int noblanks;             /* Remove insignificant spaces from XML tree */
     int preserveFormat;       /* Preserve original XML formatting */
-    int omit_decl;            /* Ommit XML declaration line <?xml version="1.0"?> */
+    int omit_decl;            /* Omit XML declaration line <?xml version="1.0"?> */
+    int inplace;              /* Edit file inplace (no output on stdout) */
 } edOptions;
 
 typedef edOptions *edOptionsPtr;
@@ -119,13 +120,14 @@ static const char edit_usage_str_2[] =
 "  -P (or --pf)        - preserve original formatting\n"
 "  -S (or --ps)        - preserve non-significant spaces\n"
 "  -O (or --omit-decl) - omit XML declaration (<?xml ...?>)\n"
+"  -L (or --inplace)   - edit file inplace\n"
 "  -N <name>=<value>   - predefine namespaces (name without \'xmlns:\')\n"
 "                        ex: xsql=urn:oracle-xsql\n"
 "                        Multiple -N options are allowed.\n"
-"                        -N options must be last global options.\n"
-"  --help or -h        - display help\n\n";
+"                        -N options must be last global options.\n";
 
 static const char edit_usage_str_3[] =
+"  --help or -h        - display help\n\n"
 "where <action>\n"
 "  -d or --delete <xpath>\n"
 "  -i or --insert <xpath> -t (--type) elem|text|attr -n <name> -v (--value) <value>\n"
@@ -171,6 +173,7 @@ edInitOptions(edOptionsPtr ops)
     ops->noblanks = 1;
     ops->omit_decl = 0;
     ops->preserveFormat = 0;
+    ops->inplace = 0;
 }
 
 /**
@@ -196,6 +199,10 @@ edParseOptions(edOptionsPtr ops, int argc, char **argv)
         {
             ops->omit_decl = 1;
         }
+        else if (!strcmp(argv[i], "-L") || !strcmp(argv[i], "--inplace"))
+        {
+            ops->inplace = 1;
+        }
         else if (!strcmp(argv[i], "--help") || !strcmp(argv[i], "-h") ||
                  !strcmp(argv[i], "-?") || !strcmp(argv[i], "-Z"))
         {
@@ -323,9 +330,10 @@ edUpdate(xmlDocPtr doc, const char *loc, const char *val, XmlNodeType type)
             comp = xmlXPathCompile(BAD_CAST loc);
             if (comp != NULL)
             {
+#if defined(LIBXML_DEBUG_ENABLED)
                 if (tree)
                     xmlXPathDebugDumpCompExpr(stdout, comp, 0);
-
+#endif
                 res = xmlXPathCompiledEval(comp, ctxt);
                 xmlXPathFreeCompExpr(comp);
             }
@@ -406,9 +414,10 @@ edInsert(xmlDocPtr doc, const char *loc, const char *val, const char *name,
             comp = xmlXPathCompile(BAD_CAST loc);
             if (comp != NULL)
             {
+#if defined(LIBXML_DEBUG_ENABLED)
                 if (tree)
                     xmlXPathDebugDumpCompExpr(stdout, comp, 0);
-
+#endif
                 res = xmlXPathCompiledEval(comp, ctxt);
                 xmlXPathFreeCompExpr(comp);
             }
@@ -508,9 +517,10 @@ edRename(xmlDocPtr doc, char *loc, char *val, XmlNodeType type)
             comp = xmlXPathCompile(BAD_CAST loc);
             if (comp != NULL)
             {
+#if defined(LIBXML_DEBUG_ENABLED)
                 if (tree)
                     xmlXPathDebugDumpCompExpr(stdout, comp, 0);
-
+#endif
                 res = xmlXPathCompiledEval(comp, ctxt);
                 xmlXPathFreeCompExpr(comp);
             }
@@ -599,9 +609,10 @@ edDelete(xmlDocPtr doc, char *str)
             comp = xmlXPathCompile(BAD_CAST str);
             if (comp != NULL)
             {
+#if defined(LIBXML_DEBUG_ENABLED)
                 if (tree)
                     xmlXPathDebugDumpCompExpr(stdout, comp, 0);
-
+#endif
                 res = xmlXPathCompiledEval(comp, ctxt);
                 xmlXPathFreeCompExpr(comp);
             }
@@ -691,9 +702,10 @@ edMove(xmlDocPtr doc, char *from, char *to)
             comp = xmlXPathCompile(BAD_CAST from);
             if (comp != NULL)
             {
+#if defined(LIBXML_DEBUG_ENABLED)
                 if (tree)
                     xmlXPathDebugDumpCompExpr(stdout, comp, 0);
-
+#endif
                 res = xmlXPathCompiledEval(comp, ctxt);
                 xmlXPathFreeCompExpr(comp);
             }
@@ -738,9 +750,10 @@ edMove(xmlDocPtr doc, char *from, char *to)
             comp = xmlXPathCompile(BAD_CAST to);
             if (comp != NULL)
             {
+#if defined(LIBXML_DEBUG_ENABLED)
                 if (tree)
                     xmlXPathDebugDumpCompExpr(stdout, comp, 0);
-
+#endif
                 res_to = xmlXPathCompiledEval(comp, ctxt);
                 xmlXPathFreeCompExpr(comp);
             }
@@ -841,6 +854,54 @@ edProcess(xmlDocPtr doc, XmlEdAction* ops, int ops_count)
     return res;
 }
 
+/**
+ *  Output document
+ */
+void
+edOutput(const char* filename, edOptions g_ops)
+{
+    xmlDocPtr doc = xmlParseFile(filename);
+
+    if (!doc)
+    {
+        edCleanupNSArr(ns_arr);
+        xmlCleanupParser();
+        xmlCleanupGlobals();
+        exit(2);
+    }
+
+    edProcess(doc, ops, ops_count);
+
+    /* Print out result */
+    if (!g_ops.omit_decl)
+    {
+        xmlSaveFormatFile(g_ops.inplace ? filename : "-", doc, 1);
+    }
+    else
+    {
+        int format = 1;
+        int ret = 0;
+        char *encoding = NULL;
+        xmlOutputBufferPtr buf = NULL;
+        xmlCharEncodingHandlerPtr handler = NULL;
+        buf = xmlOutputBufferCreateFilename(g_ops.inplace ? filename : "-", handler, 0);
+
+        if (doc->children != NULL)
+        {
+            xmlNodePtr child = doc->children;
+            while (child != NULL)
+            {
+                xmlNodeDumpOutput(buf, doc, child, 0, format, encoding);
+                xmlOutputBufferWriteString(buf, "\n");
+                child = child->next;
+            }
+        }
+        ret = xmlOutputBufferClose(buf);
+    }
+    
+    xmlFreeDoc(doc);
+}
+
 /**
  *  This is the main function for 'edit' option
  */
@@ -1059,90 +1120,12 @@ edMain(int argc, char **argv)
 
     if (i >= argc)
     {
-        xmlDocPtr doc = xmlParseFile("-");
-
-        if (!doc)
-        {
-            edCleanupNSArr(ns_arr);
-            xmlCleanupParser();
-            xmlCleanupGlobals();
-            exit(2);
-        }
-
-        edProcess(doc, ops, ops_count);
-
-        /* Print out result */
-        if (!g_ops.omit_decl)
-        {
-            xmlSaveFormatFile("-", doc, 1);
-        }
-        else
-        {
-            int format = 1;
-            int ret = 0;
-            char *encoding = NULL;
-            xmlOutputBufferPtr buf = NULL;
-            xmlCharEncodingHandlerPtr handler = NULL;
-            buf = xmlOutputBufferCreateFile(stdout, handler);
-
-            if (doc->children != NULL)
-            {
-               xmlNodePtr child = doc->children;
-               while (child != NULL)
-               {
-                  xmlNodeDumpOutput(buf, doc, child, 0, format, encoding);
-                  xmlOutputBufferWriteString(buf, "\n");
-                  child = child->next;
-               }
-            }
-            ret = xmlOutputBufferClose(buf);
-        }
-        
-        xmlFreeDoc(doc);
+        edOutput("-", g_ops);
     }
     
     for (n=i; n<argc; n++)
     {
-        xmlDocPtr doc = xmlParseFile(argv[n]);
-
-        if (!doc)
-        {
-            edCleanupNSArr(ns_arr);
-            xmlCleanupParser();
-            xmlCleanupGlobals();
-            exit(2);
-        }
-
-        edProcess(doc, ops, ops_count);
-
-        /* Print out result */
-        if (!g_ops.omit_decl)
-        {
-            xmlSaveFormatFile("-", doc, 1);
-        }
-        else
-        {
-            int format = 1;
-            int ret = 0;
-            char *encoding = NULL;
-            xmlOutputBufferPtr buf = NULL;
-            xmlCharEncodingHandlerPtr handler = NULL;
-            buf = xmlOutputBufferCreateFile(stdout, handler);
-
-            if (doc->children != NULL)
-            {
-               xmlNodePtr child = doc->children;
-               while (child != NULL)
-               {
-                  xmlNodeDumpOutput(buf, doc, child, 0, format, encoding);
-                  xmlOutputBufferWriteString(buf, "\n");
-                  child = child->next;
-               }
-            }
-            ret = xmlOutputBufferClose(buf);
-        }
-        
-        xmlFreeDoc(doc);
+        edOutput(argv[n], g_ops);
     }
 
     edCleanupNSArr(ns_arr);
