@@ -63,6 +63,7 @@ typedef struct _foOptions {
 #ifdef LIBXML_HTML_ENABLED
     int html;                 /* inputs are in HTML format */
 #endif
+    int quiet;                 /* quiet mode */
 } foOptions;
 
 typedef foOptions *foOptionsPtr;
@@ -88,6 +89,7 @@ static const char format_usage_str_2[] =
 #ifdef LIBXML_HTML_ENABLED
 "  -H or --html                - input is HTML\n"
 #endif
+"  -Q or --quiet               - Suppress errors from libxml2\n"
 "  -h or --help                - print help\n\n";
 
 const char *encoding = NULL;
@@ -122,6 +124,7 @@ foInitOptions(foOptionsPtr ops)
 #ifdef LIBXML_HTML_ENABLED
     ops->html = 0;
 #endif
+    ops->quiet = 0;
 }
 
 /**
@@ -241,6 +244,11 @@ foParseOptions(foOptionsPtr ops, int argc, char **argv)
             ops->indent_tab = 0;
             i++;
         }
+        else if (!strcmp(argv[i], "--quiet") || !strcmp(argv[i], "-Q"))
+        {
+            ops->quiet = 1;
+            i++;
+        }
 #ifdef LIBXML_HTML_ENABLED
         else if (!strcmp(argv[i], "--html") || !strcmp(argv[i], "-H"))
         {
@@ -271,6 +279,14 @@ foParseOptions(foOptionsPtr ops, int argc, char **argv)
     return i-1;
 }
 
+void my_error_func(void* ctx, const char * msg, ...) {
+  /* do nothing */
+}
+
+void my_structured_error_func(void * userData, xmlErrorPtr error) {
+  /* do nothing */
+}
+
 /**
  *  'process' xml document(s)
  */
@@ -294,6 +310,11 @@ foProcess(foOptionsPtr ops, int start, int argc, char **argv)
     }
     else    
 */
+    if (ops->quiet) {
+      xmlSetGenericErrorFunc(NULL, my_error_func);
+      xmlSetStructuredErrorFunc(NULL, my_structured_error_func);
+    }
+
 #ifdef LIBXML_HTML_ENABLED
     if (ops->html)
     {
